==> libapt-pkg-perl_0.1.4.tar.gz: libapt-pkg-perl-0.1.4/AptPkg/Version.pm <==
package AptPkg::Version;

# $Id: Version.pm,v 1.3 2002/01/03 14:17:56 bod Exp $

require 5.005_62;
use strict;
use warnings;
use AptPkg;

require Exporter;

our @ISA = qw(Exporter);
our @EXPORT_OK = qw();
our @EXPORT = ();

our $VERSION = qw$Revision: 1.3 $[1] || 0.1;

sub label       { shift->Label(@_) }
sub compare     { shift->CmpVersion(@_) }
sub rel_compare { shift->CmpReleaseVer(@_) }
sub check_dep   { shift->CheckDep(@_) }
sub upstream    { shift->UpstreamVersion(@_) }

1;

__END__

=head1 NAME

AptPkg::Version - APT package versioning class

=head1 SYNOPSIS

use AptPkg::Version;

=head1 DESCRIPTION

The AptPkg::Version module provides an interface to B<APT>'s package
version handling.

=head2 ApkPkg::Version

The AptPkg::Version package implements the B<APT> pkgVersioningSystem
class.

An instance of the ApkPkg::Version class may be fetched using the
verioning method from AptPkg::System.

The following methods are implemented:

=over 4

=item label

Return the description of the versioning system, for example:

    Standard .deb

for Debian systems.

=item compare(I<A>, I<B>)

Compare package version I<A> with I<B>, returning a negative value if
I<A> is an earlier version than I<B>, zero if the same or a positive
value if I<A> is later.

=item rel_compare(I<A>, I<B>)

Compare distribution release numbers.

=item check_dep(I<PKG>, I<OP>, I<DEP>)

Check that the package version I<PKG> satisfies the relation I<OP> to
the dependency version I<DEP>.

The relation I<OP> is specified in the Debian syntax regardless of the
versioning system:

    <<	strictly earlier
    <=	earlier or equal
    =	exactly equal
    >=	later or equal
    >>	strictly later

=item upstream(I<VER>)

Return the upstream component of the given version string.

=back

=head1 SEE ALSO

AptPkg::Config(3pm), AptPkg::System(3pm), AptPkg(3pm).

=head1 AUTHOR

Brendan O'Dea <bod@debian.org>

=cut

==> libapt-pkg-perl_0.1.12.tar.gz: libapt-pkg-perl-0.1.12/AptPkg/Version.pm <==
package AptPkg::Version;

# $Id: Version.pm,v 1.5 2003/06/10 07:09:38 bod Exp $

require 5.005_62;
use strict;
use warnings;
use AptPkg;

require Exporter;

our @ISA = qw(Exporter);
our @EXPORT_OK = qw();
our @EXPORT = ();

our $VERSION = qw$Revision: 1.5 $[1] || 0.1;

sub label       { shift->Label(@_) }
sub compare     { shift->CmpVersion(@_) }
sub rel_compare { shift->CmpReleaseVer(@_) }
sub check_dep   { shift->CheckDep(@_) }
sub upstream    { shift->UpstreamVersion(@_) }

1;

__END__

=head1 NAME

AptPkg::Version - APT package versioning class

=head1 SYNOPSIS

use AptPkg::Version;

=head1 DESCRIPTION

The AptPkg::Version module provides an interface to B<APT>'s package
version handling.

=head2 AptPkg::Version

The AptPkg::Version package implements the B<APT> pkgVersioningSystem
class.

An instance of the AptPkg::Version class may be fetched using the
versioning method from AptPkg::System.

The following methods are implemented:

=over 4

=item label

Return the description of the versioning system, for example:

    Standard .deb

for Debian systems.

=item compare(I<A>, I<B>)

Compare package version I<A> with I<B>, returning a negative value if
I<A> is an earlier version than I<B>, zero if the same or a positive
value if I<A> is later.

=item rel_compare(I<A>, I<B>)

Compare distribution release numbers.

=item check_dep(I<PKG>, I<OP>, I<DEP>)

Check that the package version I<PKG> satisfies the relation I<OP> to
the dependency version I<DEP>.

The relation I<OP> is specified in the Debian syntax regardless of the
versioning system:

    <<	strictly earlier
    <=	earlier or equal
    =	exactly equal
    >=	later or equal
    >>	strictly later

=item upstream(I<VER>)

Return the upstream component of the given version string.

=back

=head1 SEE ALSO

AptPkg::Config(3pm), AptPkg::System(3pm), AptPkg(3pm).

=head1 AUTHOR

Brendan O'Dea <bod@debian.org>

=cut
